---
name: Model Support Request
about: Suggest Model for support
title: "[MODEL]"
labels: model-request
assignees: ''

---

**Please describe your use case and why the current models may not support your need.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe a preferred serving framework**
A clear and concise description of what you want to happen.

**Link to huggingface**
Add any other context or screenshots about the feature request here.
